@@ -1,3 +1,3 @@
 from .guardpoint import GuardPoint, GuardPointError
-from .guardpoint_dataclasses import Cardholder, Card, Area, SecurityGroup
+from .guardpoint_dataclasses import SortAlgorithm, Cardholder, Card, Area, SecurityGroup
 from .guardpoint_async import GuardPointAsync
