@@ -1,6 +1,6 @@
-from asyncio import Future
 from concurrent.futures import ThreadPoolExecutor
 from .guardpoint import GuardPoint, GuardPointError
+from .guardpoint_dataclasses import SortAlgorithm, Cardholder
 
 
 class GuardPointAsync:
@@ -14,10 +14,23 @@ class GuardPointAsync:
         callback = GPAsyncCallBack(on_finished)
         future.add_done_callback(callback.handle_future)
 
-    def get_card_holders(self, on_finished, offset=0, limit=10, search_terms=None, cardholder_type_name=None, areas=None,
-                         filter_expired=False):
+    def get_card_holders(self, on_finished, offset=0, limit=10, search_terms=None, cardholder_type_name=None,
+                         areas=None,
+                         filter_expired=False, sort_algorithm=SortAlgorithm.SERVER_DEFAULT, threshold=75):
         future = self.executor.submit(self.gp.get_card_holders, offset=offset, limit=limit, search_terms=search_terms,
-                                      cardholder_type_name=cardholder_type_name, areas=areas, filter_expired=filter_expired)
+                                      cardholder_type_name=cardholder_type_name, areas=areas,
+                                      filter_expired=filter_expired,
+                                      sort_algorithm=sort_algorithm, threshold=threshold)
+        callback = GPAsyncCallBack(on_finished)
+        future.add_done_callback(callback.handle_future)
+
+    def update_cardholder(self, on_finished, cardholder: Cardholder):
+        future = self.executor.submit(self.gp.update_card_holder, cardholder=cardholder)
+        callback = GPAsyncCallBack(on_finished)
+        future.add_done_callback(callback.handle_future)
+
+    def delete_cardholder(self, on_finished, cardholder: Cardholder):
+        future = self.executor.submit(self.gp.delete_card_holder, cardholder=cardholder)
         callback = GPAsyncCallBack(on_finished)
         future.add_done_callback(callback.handle_future)
 
@@ -36,6 +49,11 @@ class GuardPointAsync:
         callback = GPAsyncCallBack(on_finished)
         future.add_done_callback(callback.handle_future)
 
+    def get_security_groups(self, on_finished):
+        future = self.executor.submit(self.gp.get_security_groups)
+        callback = GPAsyncCallBack(on_finished)
+        future.add_done_callback(callback.handle_future)
+
 
 class GPAsyncCallBack:
     on_finished = None
