@@ -3,8 +3,7 @@ import http.client
 import json
 from enum import Enum
 from json import JSONDecodeError
-from socket import error as socket_error
-from pyGuardPoint.guardpoint_utils import Stopwatch, ConvertBase64
+from .guardpoint_utils import Stopwatch, ConvertBase64
 import time
 
 
